pub enum Component {
Element {
surf_idxs: (usize, usize),
},
Stop {
stop_idx: usize,
},
UnpairedSurface {
surf_idx: usize,
},
}Expand description
A component is a part of an optical system that can interact with light rays.
Components come in two types: elements, and stops. Elements are the most basic compound optical component and are represented as a set of surfaces pairs. Stops are hard stops that block light rays.
To avoid copying data, only indexes are stored from the surface models are stored.
Variants