pub enum PupilSampling {
SquareGrid {
spacing: f64,
},
ChiefAndMarginalRays,
}Expand description
Specifies a pupil sampling method.
Variants
SquareGrid
A square grid of rays in the the entrance pupil.
Spacing is the spacing between rays in the grid in normalized pupil distances, i.e. [0, 1]. A spacing of 1.0 means that one ray will lie at the pupil center (the chief ray), and the others will lie at the pupil edge (marginal rays).
ChiefAndMarginalRays
The chief and marginal rays.
Implementations