pub struct ParaxialSubView { /* private fields */ }Expand description
A paraxial subview of an optical system.
A paraxial subview is identified by a single submodel ID that corresponds to a submodel of a sequential model. It is not created by the user, but rather by instantiating a new ParaxialView struct.
Implementations
Sourceimpl ParaxialSubView
impl ParaxialSubView
pub fn aperture_stop(&self) -> &usize
pub fn back_focal_distance(&self) -> &f64
pub fn back_principal_plane(&self) -> &f64
pub fn chief_ray(&self) -> &Array3<f64>
pub fn effective_focal_length(&self) -> &f64
pub fn entrance_pupil(&self) -> &Pupil
pub fn exit_pupil(&self) -> &Pupil
pub fn front_focal_distance(&self) -> &f64
pub fn front_principal_plane(&self) -> &f64
pub fn is_obj_space_telecentric(&self) -> &bool
pub fn marginal_ray(&self) -> &Array3<f64>
pub fn paraxial_image_plane(&self) -> &ImagePlane