ParaxialView

Struct ParaxialView 

pub struct ParaxialView { /* private fields */ }
A paraxial view into an optical system.

A paraxial view is a set of paraxial subviews that describe the first order properties of an optical system, such as the entrance and exit pupils, the back and front focal distances, and the effective focal length.

Subviews are indexed by a pair of submodel IDs.

Implementations

Source

impl ParaxialView

pub fn new( sequential_model: &SequentialModel, field_specs: &[FieldSpec], is_obj_space_telecentric: bool, ) -> Result<Self>

Creates a new ParaxialView of a SequentialModel.

Arguments
  • sequential_model - The sequential model to create a paraxial view of.
  • field_specs - The field specs of the optical system. These are necessary to compute parameters such as the chief ray.
  • is_obj_space_telecentric - Whether the object space is telecentric. This forces the chief ray to be parallel to the optic axis.
Returns

A new ParaxialView.

pub fn describe(&self) -> ParaxialViewDescription

Returns a description of the paraxial view.

This is used primarily for serialization of data for export.

Returns

A description of the paraxial view.

pub fn subviews(&self) -> &HashMap<SubModelID, ParaxialSubView>

Returns the subviews of the paraxial view.

Each subview corresponds to a submodel of the sequential model.

Returns

The subviews of the paraxial view.