pub type Step<'a> = (&'a Gap, &'a Surface, Option<&'a Gap>);Expand description
A single ray tracing step in a sequential system.
See the documentation for SequentialSubModel for more information.
pub type Step<'a> = (&'a Gap, &'a Surface, Option<&'a Gap>);A single ray tracing step in a sequential system.
See the documentation for SequentialSubModel for more information.