Crate cherry_rs

source

Modules

Structs

Enums

  • Specifies the system aperture.
  • A component is a part of an optical system that can interact with light rays.
  • Specifies an object field.
  • Specifies the imaginary part of a refractive index.
  • Specifies a pupil sampling method.
  • Specifies the real part of a refractive index.
  • Specifies a surface in a sequential optical system model.
  • Specifies the type of interaction of light with a sequential model surface.

Traits

Functions

Type Aliases