Modules
Structs
- Specifies a gap in a sequential optical system model.
- A paraxial description of an optical system.
- A paraxial entrance or exit pupil.
- A single ray to be traced through an optical system.
- Specifies the refractive index of the material constituting a gap.
- A collection of submodels for sequential ray tracing.
- A unique identifier for a submodel.
Enums
- Specifies the system aperture.
- A component is a part of an optical system that can interact with light rays.
- Specifies an object field.
- Specifies the imaginary part of a refractive index.
- Specifies a pupil sampling method.
- Specifies the real part of a refractive index.
- Specifies a surface in a sequential optical system model.
- Specifies the type of interaction of light with a sequential model surface.