cherry_rs

Struct Ray

source
pub struct Ray { /* private fields */ }
A single ray to be traced through an optical system.

Attributes

  • pos: Position of the ray
  • dir: Direction of the ray (direction cosines)

Implementations

source

impl Ray

source

pub fn new(pos: Vec3, dir: Vec3, field_id: usize) -> Result<Self>

source

pub fn intersect(&self, surf: &Surface, max_iter: usize) -> Result<(Vec3, Vec3)>

Finds the intersection point of a ray with a surface and the surface normal at that point.

If no intersection is found, then this function returns an error.

Arguments
  • surf: Surface to intersect with
  • max_iter: Maximum number of iterations for the Newton-Raphson method
source

pub fn redirect( &mut self, step: &(&'_ Gap, &'_ Surface, Option<&'_ Gap>), norm: Vec3, )

source

pub fn displace(&mut self, pos: Vec3)

Displace a ray to the given location.

source

pub fn transform(&mut self, surf: &Surface)

Transform a ray into the local coordinate system of a surface from the global system.

source

pub fn i_transform(&mut self, surf: &Surface)

Transform a ray from the local coordinate system of a surface into the global system.

source

pub fn terminate(&mut self)

source

pub fn is_terminated(&self) -> bool

source

pub fn fan( n: usize, r: f64, theta: f64, z: f64, phi: f64, radial_offset_x: f64, radial_offset_y: f64, field_id: usize, ) -> Vec<Ray>

Create a fan of uniformly spaced rays in a given z-plane at an angle phi to the z-axis.

The vectors have endpoints at an angle theta with respect to the x-axis and extend from distances -r to r from the point (0, 0, z). The rays are at an angle phi from the z-axis.

Arguments
  • n: Number of vectors to create
  • r: Radial span of vector endpoints from [-r, r]
  • theta: Angle of vectors with respect to x, radians
  • z: z-coordinate of endpoints
  • phi: Angle of vectors with respect to z, the optics axis, radians
  • radial_offset_x: Offset the radial position of the vectors by this amount in x
  • radial_offset_y: Offset the radial position of the vectors by this amount in y