cherry_rs

Struct SequentialModel

source
pub struct SequentialModel { /* private fields */ }
A collection of submodels for sequential ray tracing.

Implementations

source

impl SequentialModel

source

pub fn new( gap_specs: &[GapSpec], surface_specs: &[SurfaceSpec], wavelengths: &[f64], ) -> Result<Self>

Creates a new sequential model of an optical system.

source

pub fn surfaces(&self) -> &[Surface]

source

pub fn submodels(&self) -> &HashMap<SubModelID, impl SequentialSubModel>

source

pub fn largest_semi_diameter(&self) -> f64

Returns the largest semi-diameter of any surface in the system.

This ignores surfaces without any size, such as object, probe, and image surfaces.